**Example 1: 删除空间**



Input: 

```
tccli oceanus DeleteWorkSpace --cli-unfold-argument  \
    --WorkSpaceId space-1327
```

Output: 
```
{
    "Response": {
        "Delete": true,
        "RequestId": "xx"
    }
}
```

